#[non_exhaustive]pub struct CreatePaymentManagerOutput {
pub payment_manager_arn: String,
pub payment_manager_id: String,
pub name: String,
pub authorizer_type: PaymentsAuthorizerType,
pub authorizer_configuration: Option<AuthorizerConfiguration>,
pub role_arn: String,
pub workload_identity_details: Option<WorkloadIdentityDetails>,
pub created_at: DateTime,
pub status: PaymentManagerStatus,
pub tags: Option<HashMap<String, String>>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.payment_manager_arn: StringThe Amazon Resource Name (ARN) of the created payment manager.
payment_manager_id: StringThe unique identifier of the created payment manager.
name: StringThe name of the created payment manager.
The type of authorizer for the created payment manager.
Represents inbound authorization configuration options used to authenticate incoming requests.
role_arn: StringThe Amazon Resource Name (ARN) of the IAM role associated with the created payment manager.
workload_identity_details: Option<WorkloadIdentityDetails>The information about the workload identity.
created_at: DateTimeThe timestamp when the payment manager was created.
status: PaymentManagerStatusThe current status of the payment manager. Possible values include CREATING, READY, UPDATING, DELETING, CREATE_FAILED, UPDATE_FAILED, and DELETE_FAILED.
The tags associated with the created payment manager.
Implementations
Sourceimpl CreatePaymentManagerOutput
impl CreatePaymentManagerOutput
Sourcepub fn payment_manager_arn(&self) -> &str
pub fn payment_manager_arn(&self) -> &str
The Amazon Resource Name (ARN) of the created payment manager.
Sourcepub fn payment_manager_id(&self) -> &str
pub fn payment_manager_id(&self) -> &str
The unique identifier of the created payment manager.
The type of authorizer for the created payment manager.
Represents inbound authorization configuration options used to authenticate incoming requests.
Sourcepub fn role_arn(&self) -> &str
pub fn role_arn(&self) -> &str
The Amazon Resource Name (ARN) of the IAM role associated with the created payment manager.
Sourcepub fn workload_identity_details(&self) -> Option<&WorkloadIdentityDetails>
pub fn workload_identity_details(&self) -> Option<&WorkloadIdentityDetails>
The information about the workload identity.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the payment manager was created.
Sourcepub fn status(&self) -> &PaymentManagerStatus
pub fn status(&self) -> &PaymentManagerStatus
The current status of the payment manager. Possible values include CREATING, READY, UPDATING, DELETING, CREATE_FAILED, UPDATE_FAILED, and DELETE_FAILED.
The tags associated with the created payment manager.
Sourceimpl CreatePaymentManagerOutput
impl CreatePaymentManagerOutput
Sourcepub fn builder() -> CreatePaymentManagerOutputBuilder
pub fn builder() -> CreatePaymentManagerOutputBuilder
Creates a new builder-style object to manufacture CreatePaymentManagerOutput.