#[non_exhaustive]pub struct GetConfigurationBundleOutput {
pub bundle_arn: String,
pub bundle_id: String,
pub bundle_name: String,
pub description: Option<String>,
pub version_id: String,
pub components: HashMap<String, ComponentConfiguration>,
pub lineage_metadata: Option<VersionLineageMetadata>,
pub created_at: DateTime,
pub updated_at: DateTime,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bundle_arn: StringThe Amazon Resource Name (ARN) of the configuration bundle.
bundle_id: StringThe unique identifier of the configuration bundle.
bundle_name: StringThe name of the configuration bundle.
description: Option<String>The description of the configuration bundle.
version_id: StringThe version identifier of this configuration bundle.
components: HashMap<String, ComponentConfiguration>A map of component identifiers to their configurations for this version.
lineage_metadata: Option<VersionLineageMetadata>The version lineage metadata, including parent versions, branch name, and creation source.
created_at: DateTimeThe timestamp when the configuration bundle was created.
updated_at: DateTimeThe timestamp when the configuration bundle was last updated.
Implementations
Sourceimpl GetConfigurationBundleOutput
impl GetConfigurationBundleOutput
Sourcepub fn bundle_arn(&self) -> &str
pub fn bundle_arn(&self) -> &str
The Amazon Resource Name (ARN) of the configuration bundle.
Sourcepub fn bundle_name(&self) -> &str
pub fn bundle_name(&self) -> &str
The name of the configuration bundle.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The description of the configuration bundle.
Sourcepub fn version_id(&self) -> &str
pub fn version_id(&self) -> &str
The version identifier of this configuration bundle.
Sourcepub fn components(&self) -> &HashMap<String, ComponentConfiguration>
pub fn components(&self) -> &HashMap<String, ComponentConfiguration>
A map of component identifiers to their configurations for this version.
Sourcepub fn lineage_metadata(&self) -> Option<&VersionLineageMetadata>
pub fn lineage_metadata(&self) -> Option<&VersionLineageMetadata>
The version lineage metadata, including parent versions, branch name, and creation source.
Sourcepub fn created_at(&self) -> &DateTime
pub fn created_at(&self) -> &DateTime
The timestamp when the configuration bundle was created.
Sourcepub fn updated_at(&self) -> &DateTime
pub fn updated_at(&self) -> &DateTime
The timestamp when the configuration bundle was last updated.
Sourceimpl GetConfigurationBundleOutput
impl GetConfigurationBundleOutput
Sourcepub fn builder() -> GetConfigurationBundleOutputBuilder
pub fn builder() -> GetConfigurationBundleOutputBuilder
Creates a new builder-style object to manufacture GetConfigurationBundleOutput.